@@ -18,16 +18,6 @@
 #define EXTRA_SLEEP_TIME 0
 #endif
 
-#ifndef CDINDEX_HOME
-#define CDINDEX_HOME ".cdindex"
-#endif
-
-#ifndef NETWORK_CAPABLE
-#define NETWORK_CAPABLE FALSE
-#else
-#define NETWORK_CAPABLE TRUE
-#endif
-
 int sigterm_handler (int sig);
 int sigusr1_handler (int sig);
 
