@@ -1,14 +1,14 @@
 #ifndef __MBO_H
 #define __MBO_H
 
+#ifdef NETWORK
 #include <musicbrainz/mb_c.h>
+#endif
 
 int mbo_init(char *device);
 char *mbo_trackname (int i);
 
 #define CDI_HOME ".cdindex" 	/* for historical reasons */
-#define USE_NETWORK 1		/* see above */
-// #define USE_NETWORK 0
 
 #define MBO_SERVER "www.musicbrainz.org"
 
