@@ -1,3 +1,4 @@
+/* $Revision: 1.4 $ */
 /* screenop.c - screen/display bits for dcd
  * (C) 1999 David E. Smith (dave@technopagan.org)
  * Released under GNU GPL, see `COPYING' for details.
@@ -22,8 +23,8 @@ void disk_directory(void) {
     fprintf (stderr, "Entering directory. tz is %i\n", cd_last_track());
   #endif
 
-  sprintf (outline, "Track  Time  (%i tracks / %2i:%02i)",
-          cd_last_track(), disc_length/60, disc_length%60);
+  sprintf (outline, "Track  Time  (%i tracks / %2i:%02i) %30s",
+          cd_last_track(), disc_length/60, disc_length%60, mbo_trackname(0));
   printf ("%s\n", outline);
   
   for (i=1; i<=cd_last_track(); i++) {
@@ -94,7 +95,9 @@ void print_help (void) {
 void dcd_version (void) {
   printf ("%s\n", VERSION);
   printf ("Compiled on %s with default drive %s\n", __DATE__,CDROM_DEVICE);
-  printf ("Includes MiniLZO %s by Markus F.X.J. Oberhumer\n", LZO_VERSION_STRING);
+  #ifdef NETWORK
+    printf ("Includes MiniLZO %s by Markus F.X.J. Oberhumer\n", LZO_VERSION_STRING);
+  #endif
 }
 
 void print_discid(void) {
